"use strict";

/**
 * Ecap.
 */
var FoolEcap = (function($, window, document) {
    var submitErrors = [];

    /**
     * Determine if valid email address.
     *
     * @see http://stackoverflow.com/questions/46155/validate-email-address-in-javascript
     *
     * @return bool
     */
    function validEmail(email) {
        var re = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;

        return re.test(email);
    }

    /**
     * Determine if valid phone number localized by brand code.
     *
     * @return bool
     */
    function validPhoneNumber(phoneNumber) {
        if (SiteInfo.brandCode === "camf") {
            var re = /^\d{3}-\d{3}-\d{4}$/;

            return re.test(phoneNumber);
        }

        return false;
    }

    /**
     * Get clientId value from Google Analytics command queue (ultimately GA cookie).
     *
     * @return string Client ID
     */
    function getClientId() {
        var clientId = "";

        if (window.ga && ga.create) {
            window.ga(function(tracker) {
                clientId = tracker.get("clientId");
            });
        }

        return clientId;
    }

    /**
     * Manage ookie cookie and its value.
     *
     * Possible ookie values:
     *   -1: user logged in or ecapped
     *    1:
     *    2: tickle is shown on article page (those with element of ID #full_content in DOM)
     *
     * @return void
     */
    function manageCookie() {
        if (!isFoolBaseDefined()) {
            return;
        }

        if ($("#full_content").length || $("#ecap-27").length) {
            Fool.Base.setCookie(window.FoolEcapData.ookie);
        }

        if (Fool.Base.getCookie(window.FoolEcapData.ookie) >= (window.FoolEcapData.ookieTickle + 1)) {
            Fool.Base.resetCookie(window.FoolEcapData.ookie);
        }
    }

    function isFoolBaseDefined() {
        return !(typeof Fool.Base === "undefined");
    }

    $(document).ready(function() {
        manageCookie();
        checkWindowSize();

        $(".fool-ecap form").submit(function(event) {
            // Disable submit button.
            $(this).find("input:submit").attr("disabled", "disabled");

            // Clear submit errors.
            submitErrors = [];

            // Prevent default form submit.
            event.preventDefault();

            // Check for presence of accept terms checkbox and fail if it is not checked.
            if ($(this).find(".accept-terms-checkbox").length) {
                if (!$(this).find(".accept-terms-checkbox").is(':checked')) {
                    submitErrors.push(window.FoolEcapData.acceptTermsCheckboxUncheckedError);
                }
            }

            // Check for presence of investing style options and fail if one is not selected.
            if ($(this).find(".investing-style-wrapper").length) {
                if (!$(this).find("input[name=investingStyle]:checked").length) {
                    submitErrors.push(window.FoolEcapData.investingStyleNotSelectedError);
                }
            }

            // Check for presence of phone number field and fail if not valid.
            if ($(this).find(".phone-number").length && $(this).find(".phone-number").val().trim() !== "" && !validPhoneNumber($(this).find(".phone-number").val().trim())) {
                submitErrors.push(window.FoolEcapData.invalidPhoneNumberError);
            }

            // Check for valid email address client-side.
            if (!validEmail($(this).find(".email").val())) {
                submitErrors.push(window.FoolEcapData.invalidEmailAddressError);
            }

            // Handle errors.
            if (submitErrors.length > 0) {
                // Show the first error encountered.
                $(this).find(".ecap-error p").html(submitErrors[0]);
                $(this).find(".ecap-error").show("fast");

                // Enable submit button.
                $(this).find("input:submit").removeAttr("disabled");

                return false;
            }

            // Send data to back-end.
            $.ajax({
                "method": "POST",
                "url": window.FoolEcapData.adminAjaxUrl,
                "data": {
                    "action": "fool_ecap_submit",
                    "clientId": getClientId(),
                    "form": $(this).serialize() // Capture data.
                },
                "context": this
            })
            .done(function(data) {
                if (data.success) {
                    // Display feedback (update state).
                    $(this).html('<div class="ecap-success">' + data.message + "</div>");

                    data.type === 'tickle' && FoolEcapTickle.success();

                    window.dataLayer = window.dataLayer || []
                      window.dataLayer.push({
                       'event': 'fool.ecapSubmit'
                    });

                } else {
                    $(this).find(".ecap-error p").html(data.message);
                    $(this).find(".ecap-error").show("fast");
                }

                // Enable submit button.
                $(this).find("input:submit").removeAttr("disabled");

                if (data.success && data.redirectUrl != "") {
                    window.location = data.redirectUrl;
                }
            })
            .fail(function () {
                $(this).find(".ecap-error").html(window.FoolEcapData.unknownErrorException);

                // Enable submit button.
                $(this).find("input:submit").removeAttr("disabled");
            });
        });
    });
    /**
     * Determine which ecap should display based on window (re)size.
     * 
     */
    function checkWindowSize() {

        // Run test on initial page load
        ecapWidgetVisibility();

        // Run test on resize of the window
        $(window).resize(ecapWidgetVisibility);
    }


    // 
    function ecapWidgetVisibility(){
        // If ecap widgets exist in both aside and content, show only the former on desktop and only the latter on mobile (<1024px).
        if ($(".single-post #main-sidebar .fool-ecap-type-vanilla").length && $(".single-post article .fool-ecap-type-vanilla").length ){
            if (window.matchMedia("(min-width: 1024px)").matches) {
                $(".single-post article .fool-ecap-type-vanilla").hide();
                $(".single-post #main-sidebar .fool-ecap-type-vanilla").show();
            } else {
                $(".single-post #main-sidebar .fool-ecap-type-vanilla").hide();
                $(".single-post article .fool-ecap-type-vanilla").show();
            }
        }
    }
}(jQuery, window, document));
