(function ($, window, document) {
    /**
     * Is ad is in view and visible to user?
     *
     * @param object element Element to check if element is in view (scrolled past, really)
     *
     * @return bool
     */
    function adIsInView(element) {
        // Check if element is visible. Tickle could hide ads from user view and those should not be counted.
        if (!$(element).is(":visible")) {
            return false;
        }

        var distanceBottom = $(element).offset().top + $(element).height() - $(window).height();

        return ($(window).scrollTop() > distanceBottom);
    }

    /**
     * Are ad placement and name valid?
     *
     * @param string dataFoolAdPlacment Ad placement
     * @param string dataFoolAdName Ad name
     *
     * @return bool
     */
    function adDataIsValid(dataFoolAdPlacment, dataFoolAdName) {
        return (dataFoolAdPlacment != undefined && dataFoolAdName != undefined && dataFoolAdPlacment != '' && dataFoolAdName != '');
    }

    /**
     * Was the Google Analytics JavaScript loaded?
     *
     * @see https://davidwalsh.name/detecting-google-analytics
     *
     * @return bool
     */
    function googleAnalyticsIsLoaded() {
        return (window.ga && window.ga.create);
    }

    function processAdViews() {
        // Loop through elements with data-fool-ad-view attribute and check if they are in view.
        $("[data-fool-ad-view]").each(function(index, element) {
            if (adIsInView(element)) {
                var dataFoolAdPlacment = $(element).attr("data-fool-ad-placement");
                var dataFoolAdName = $(element).attr("data-fool-ad-name");

                if (adDataIsValid(dataFoolAdPlacment, dataFoolAdName)) {
                    // Track AdView event.
                    window.foolTracker.track("AdView", dataFoolAdPlacment, dataFoolAdName);
                } else {
                    // TODO: Add error event.
                }

                // Remove data attribute from element to eliminate duplicate events.
                $(element).removeAttr("data-fool-ad-view");
            }
        });
    }

    /**
     * Delay function execution as long as it is continued to be invoked.
     *
     * @param function func Function to delay
     * @param int wait Millisecond delay 
     * @param bool immediate 
     *
     * @see https://davidwalsh.name/essential-javascript-functions
     *
     * @return function
     */
    function debounce(func, wait, immediate) {
        var timeout;
        return function() {
            var context = this, args = arguments;
            var later = function() {
                timeout = null;
                if (!immediate) func.apply(context, args);
            };
            var callNow = immediate && !timeout;
            clearTimeout(timeout);
            timeout = setTimeout(later, wait);
            if (callNow) func.apply(context, args);
        };
    }

    // Wait until ready to attach event listeners.
    $(document).ready(function() {
        // Bind event handler to "scroll" for global window.
        $(window).scroll(debounce(function(event) {
            processAdViews();
        }, 250));
    });
}(jQuery, window, document));
