/* QUOTEAPI config - documentation athttps://quoteapi.com/docs */

function quoteapiSetup(setup)
{
    var config = {
        appID: script_vars.app_id,
        market: script_vars.market,
        startup: {
            enable: true,
            continueSetup: continue_setup
        },
        contexts: {
            "default": {
                liveness: "delayed",
                symbol: script_vars.ticker,
            },
            xjo: {
                symbol: 'xjo',
                liveness: "live",
            },
            aord: {
                symbol: 'xao',
                liveness: "delayed",
            },
        },
        formatting: {
            textOnly: true,
            changes: {
                showCurrency: false,
                showSign: false
            },
            pcts: {
                minDecimals: 2,
                maxDecimals: 2
            },
            pctChanges: {
                showSign: true,
                minDecimals: 1
            },
            times: {
                dateTimes: function (time) {
                    var hhmm = time.getHours() * 100 + time.getMinutes();
                    if (hhmm < 1610 && hhmm > 1000) {
                        return "[as at] D MMM h:mma";
                    } else {
                        return "[as at] D MMM - [Closed]";
                    }
                },
            },
        },
        options: {
            noDollars: {
                showCurrency: false
            },
            pct: {
                prepend: "(",
                append: ")"
            },
            arrows: {
                positiveCSS: "arrow-up",
                negativeCSS: "arrow-down"
            }
        },
        components: {
            indexChart: {
                component: "priceChart3",
                range: "1d",
                liveness: "delayed",
                fixedDayRange: true,
                prevClose:{
                    visible:true
                }
            },
        }
    };

    var before_1020_config = {
        // change every context's liveness to "overnight"
        contexts: {
            "default": {
                liveness: "overnight"
            },
            xjo: {
                symbol: 'xjo',
                liveness: "overnight"
            },
            aord: {
                symbol: 'xao',
                liveness: "overnight"
            },
        },
        components: {
            indexChart: {
                component: "priceChart3",
                range: "5d",
                liveness: "delayed",
                fixedDayRange: true,
                prevClose:{
                    visible:true
                }
            },
        },
    };
    /*
    This allows you to choose to show yesterday's prices up
    until the time of your choosing.
    the time is cached in local storage so it will not usually
    cause an actual network request.
    */
    function continue_setup(continue_fn)
    {
        quoteapi.request.cachedTime("asx", function (err, time) {
            if ( before(time, 1020) && !err) {
                jQuery('.risers_fallers_small').hide();
                continue_fn(before_1020_config);
            } else {
                continue_fn();
            }
        });
    }

    // times are javascript Date objects in *ASX local time*
    function before(time, cutoff_hhmm)
    {
        var local_time = time.localTime;
        var calendar_date = local_time.toDateString();
        var trading_date = time.tradingDate.toDateString();
        var hhmm = local_time.getHours() * 100 + local_time.getMinutes();

        return trading_date === calendar_date && hhmm <= cutoff_hhmm;
    }

    return config;
};
