/**
 * Update the src attribute of the image to the fallback image URL.
 *
 * This function should only be run as a listener for the error event.
 *
 * @param img HTMLImageElement
 *
 * @return void
 */
window.freesiteImageFallbackFix = function(img) {
    if (!('FOOL_IMAGE_FALLBACK' in window)) {
        return;
    }
    if (img.parentElement.nodeName == 'A' && img.parentElement.href == img.src) {
        img.parentElement.href = FOOL_IMAGE_FALLBACK.URL;
    }
    img.src = FOOL_IMAGE_FALLBACK.URL;
    img.alt = 'Image not found.';
};

/**
 * Scan the document for missing images which have been replaced.
 *
 * Remove empty figcaptions from document layout.
 */
window.addEventListener('load', function() {
    if (!('FOOL_IMAGE_FALLBACK' in window)) {
        return;
    }
    setTimeout(function() {
        var i, count = 0, img, imgs = document.getElementsByTagName('img');
        for (i = 0; i < imgs.length; i++) {
            img = imgs[i];
            if (img.src == FOOL_IMAGE_FALLBACK.URL) {
                count++;
                if (img.nextElementSibling &&
                    img.nextElementSibling.nodeName == 'FIGCAPTION' &&
                    img.nextElementSibling.innerText.trim() == ''
                ) {
                    img.nextElementSibling.style.display = 'none';
                }
            }
        }
        if (count) {
            console.warn('Found replaced missing image.');
        }
    }, 1000);
});
